@@ -1,3 +1,5 @@
+use 5.008;
+
 package Business::ISBN13;
 use strict;
 use base qw(Business::ISBN);
@@ -5,16 +7,11 @@ use base qw(Business::ISBN);
 use Business::ISBN qw(:all);
 use Data::Dumper;
 
-use vars qw(
-	$VERSION
-	$debug
-	);
-
 use Carp qw(carp croak cluck);
 
 my $debug = 0;
 
-$VERSION   = '3.002';
+our $VERSION   = '3.011';
 
 sub _max_length { 13 }
 
@@ -71,7 +68,6 @@ sub _checksum {
 
 	return unless defined $data;
 
-	my @digits = split //, $data;
 	my $sum    = 0;
 
 	foreach my $index ( 0, 2, 4, 6, 8, 10 )
@@ -114,12 +110,13 @@ This source is in Github.
 
 =head1 AUTHOR
 
-brian d foy C<< <bdfoy@cpan.org> >>
+brian d foy C<< <briandfoy@pobox.com> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2001-2016, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright © 2001-2025, brian d foy <briandfoy@pobox.com>. All rights reserved.
 
-You may redistribute this under the same terms as Perl itself.
+This module is licensed under the Artistic License 2.0. See the LICENSE
+file in the distribution, or https://opensource.org/licenses/Artistic-2.0
 
 =cut
